// THE GAME ITSELF

import nipplejs from 'nipplejs';
import { GameOptions } from './gameOptions';

// this class extends Scene class
export class PlayGame extends Phaser.Scene {

    constructor() {
        super({
            key : 'PlayGame'
        });
    }

    // the player
    player : Phaser.Physics.Arcade.Sprite;

    // method to be called once the instance has been created
    create() : void {

        // add player sprite, a physics sprite
        this.player = this.physics.add.sprite(this.game.config.width as number / 2, this.game.config.height as number / 2, 'player');  

        // create a joystick manager, leaving all default options
        let joystickManager : nipplejs.JoystickManager = nipplejs.create({});
        
        // listener to be triggered when the joystick moves
        joystickManager.on('move',  (data : nipplejs.EventData, output : nipplejs.JoystickOutputData) => {
            
            // get the force and don't let it be greater than 1
            let force : number = Math.min(output.force, 1);

            // get the angle, in radians
            let angle : number = output.angle.radian;

            // determine the speed, according to force and player speed
            let speed : number = GameOptions.playerSpeed * force;

            // set player velocity using trigonometry
            this.player.setVelocity(speed * Math.cos(angle), speed * Math.sin(angle) * -1);
        });

        // listener to be triggered when the joystick stops moving
        joystickManager.on('end',  () => {

            // stop the player
            this.player.setVelocity(0, 0);
        })
    }
}